#[non_exhaustive]pub struct OrderedListData {
pub start: Option<i64>,
}Available on crate feature
matrix only.Expand description
The supported data of a <ol> HTML element.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.start: Option<i64>An integer to start counting from for the list items.
If parsing the integer from a string fails, the attribute will be in the attrs list of
MatrixElementData.